@@ -21,10 +21,9 @@ class DownloadOrderPlugin : public Plugin, public ViewListener
 {
     Q_OBJECT
 public:
-    DownloadOrderPlugin(QObject *parent, const QVariantList &args);
+    DownloadOrderPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
     ~DownloadOrderPlugin() override;
 
-    bool versionCheck(const QString &version) const override;
     void load() override;
     void unload() override;
     void currentTorrentChanged(bt::TorrentInterface *tc) override;
