@@ -18,10 +18,9 @@ class ShutdownPlugin : public kt::Plugin
 {
     Q_OBJECT
 public:
-    ShutdownPlugin(QObject *parent, const QVariantList &args);
+    ShutdownPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
     ~ShutdownPlugin() override;
 
-    bool versionCheck(const QString &version) const override;
     void unload() override;
     void load() override;
 
