@@ -1,22 +1,7 @@
-/***************************************************************************
- *   Copyright © 2007 by Krzysztof Kundzicz                                *
- *   athantor@gmail.com                                                    *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Krzysztof Kundzicz <athantor@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef PlainChartDrawer_H_
 #define PlainChartDrawer_H_
@@ -109,7 +94,7 @@ public:
     /** \brief Constructor
     \param p Parent
     */
-    PlainChartDrawer(QWidget *p = 0);
+    PlainChartDrawer(QWidget *p = nullptr);
     /// Destructor
     ~PlainChartDrawer() override;
 
